@@ -1,5 +1,8 @@
 #' Check that an argument is an atomic vector
 #'
+#' @description
+#' For the definition of \dQuote{atomic}, see \code{\link[base]{is.atomic}}.
+#'
 #' @templateVar fn Atmoic
 #' @template x
 #' @inheritParams checkVector
@@ -7,6 +10,8 @@
 #' @family basetypes
 #' @useDynLib checkmate c_check_atomic
 #' @export
+#' @family basetypes
+#' @family atomicvector
 #' @examples
 #' testAtomic(letters, min.len = 1L, any.missing = FALSE)
 checkAtomic = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL) {
@@ -28,3 +33,12 @@ testAtomic = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min
   res = .Call("c_check_atomic", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
   isTRUE(res)
 }
+
+#' @rdname checkAtomic
+#' @template expect
+#' @useDynLib checkmate c_check_atomic
+#' @export
+expect_atomic = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL, info = NULL, label = NULL) {
+  res = .Call("c_check_atomic", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
+  makeExpectation(res, info = info, label = vname(x, label))
+}
