@@ -45,6 +45,15 @@ testCharacter = function(x, min.chars = NULL, pattern = NULL, fixed = FALSE, ign
   isTRUE(res) && isTRUE(checkCharacterProps(x, pattern, fixed, ignore.case))
 }
 
+#' @rdname checkCharacter
+#' @template expect
+#' @useDynLib checkmate c_check_character
+#' @export
+expect_character = function(x, min.chars = NULL, pattern = NULL, fixed = FALSE, ignore.case = FALSE, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL,  unique = FALSE, names = NULL, info = NULL, label = NULL) {
+  res = .Call("c_check_character", x, min.chars, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate") %and% checkCharacterProps(x, pattern, fixed, ignore.case)
+  makeExpectation(res, info = info, label = vname(x, label))
+}
+
 checkCharacterProps = function(x, pattern = NULL, fixed = FALSE, ignore.case = FALSE) {
   if (!is.null(pattern)) {
     qassert(pattern, "S1")
