@@ -27,12 +27,19 @@ checkClass = function(x, classes, ordered = FALSE) {
   qassert(ordered, "B1")
   ord = inherits(x, classes, TRUE)
   w = wf(ord == 0L)
-  if (length(w) > 0L)
-    return(sprintf("Must have class '%s'", classes[w]))
+
+  if (length(w) > 0L) {
+    cl = class(x)
+    return(sprintf("Must have class '%s', but has class%s '%s'",
+        classes[w], if (length(cl) > 1L) "es" else "", collapse(cl, "','")))
+  }
   if (ordered) {
     w = wf(ord != seq_along(ord))
-    if (length(w) > 0L)
-      return(sprintf("Must have class '%s' in position %i", classes[w], w))
+    if (length(w) > 0L) {
+      cl = class(x)
+      return(sprintf("Must have class '%s' in position %i, but has class%s '%s'",
+        classes[w], w, if (length(cl) > 1L) "es" else "", collapse(cl, "','")))
+    }
   }
   return(TRUE)
 }
@@ -47,5 +54,14 @@ assertClass = function(x, classes, ordered = FALSE, .var.name) {
 #' @rdname checkClass
 #' @export
 testClass = function(x, classes, ordered = FALSE) {
-  isTRUE(checkClass(x, classes, ordered))
+  res = checkClass(x, classes, ordered)
+  isTRUE(res)
+}
+
+#' @rdname checkClass
+#' @template expect
+#' @export
+expect_class = function(x, classes, ordered = FALSE, info = NULL, label = NULL) {
+  res = checkClass(x, classes, ordered)
+  makeExpectation(res, info = info, label = vname(x, label))
 }
