@@ -33,3 +33,12 @@ testIntegerish = function(x, tol = sqrt(.Machine$double.eps), lower = -Inf, uppe
   res = .Call("c_check_integerish", x, tol, lower, upper, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
   isTRUE(res)
 }
+
+#' @rdname checkIntegerish
+#' @template expect
+#' @useDynLib checkmate c_is_integerish
+#' @export
+expect_integerish = function(x, tol = sqrt(.Machine$double.eps), lower = -Inf, upper = Inf, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL, info = NULL, label = NULL) {
+  res = .Call("c_check_integerish", x, tol, lower, upper, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
+  makeExpectation(res, info = info, label = vname(x, label))
+}
