@@ -9,8 +9,7 @@
 #'  \item{Does no file under path \code{x} exist?}
 #'  \item{Is \code{dirname(x)} writeable?}
 #' }
-#'
-#' A string without slashes is interpreted as a file in the current working directory.
+#' Paths are relative to the current working directory.
 #'
 #' @templateVar fn PathForOutput
 #' @template x
@@ -54,5 +53,14 @@ assertPathForOutput = function(x, overwrite = FALSE, .var.name) {
 #' @rdname checkPathForOutput
 #' @export
 testPathForOutput = function(x, overwrite = FALSE) {
-  isTRUE(checkPathForOutput(x, overwrite))
+  res = checkPathForOutput(x, overwrite)
+  isTRUE(res)
+}
+
+#' @rdname checkPathForOutput
+#' @template expect
+#' @export
+expect_path_for_output = function(x, overwrite = FALSE, info = NULL, label = NULL) {
+  res = checkPathForOutput(x, overwrite)
+  makeExpectation(res, info = info, label = vname(x, label))
 }
