@@ -13,6 +13,7 @@
 #' @examples
 #' testSubset(c("a", "z"), letters)
 #' testSubset("ab", letters)
+#' testSubset("Species", names(iris))
 checkSubset = function(x, choices, empty.ok = TRUE) {
   qassert(choices, "a+")
   qassert(empty.ok, "B1")
@@ -33,5 +34,14 @@ assertSubset = function(x, choices, empty.ok = TRUE, .var.name) {
 #' @rdname checkSubset
 #' @export
 testSubset = function(x, choices, empty.ok = TRUE) {
-  isTRUE(checkSubset(x, choices, empty.ok))
+  res = checkSubset(x, choices, empty.ok)
+  isTRUE(res)
+}
+
+#' @rdname checkSubset
+#' @template expect
+#' @export
+expect_subset = function(x, choices, empty.ok = TRUE, info = NULL, label = NULL) {
+  res = checkSubset(x, choices, empty.ok)
+  makeExpectation(res, info = info, label = vname(x, label))
 }
