@@ -1,7 +1,7 @@
 vname = function(x, var.name) {
-  if (!missing(var.name))
+  if (!missing(var.name) && !is.null(var.name))
     return(var.name)
-  deparse(substitute(x, parent.frame(1L)))
+  collapse(deparse(substitute(x, parent.frame(1L)), width.cutoff = 500), "\n")
 }
 
 makeAssertion = function(msg, var.name) {
@@ -10,6 +10,11 @@ makeAssertion = function(msg, var.name) {
   invisible(TRUE)
 }
 
+makeExpectation = function(res, info, label) {
+  cond = function(tmp) expectation(isTRUE(res), res, "all good")
+  expect_that(1, cond, info = info, label = label)
+}
+
 mstop = function(msg, ...) {
   stop(simpleError(sprintf(msg, ...), call = sys.call(1L)))
 }
@@ -42,3 +47,7 @@ collapse = function(x, sep = ",") {
 "%nin%" = function(x, y) {
   !match(x, y, nomatch = 0L)
 }
+
+killCamel = function(x) {
+  gsub("([A-Z])", "_\\L\\1", x, perl = TRUE)
+}
