@@ -9,33 +9,11 @@
 #include "all_nchar.h"
 #include "helper.h"
 
+#define assert(x) ({ msg_t tmp = x; if (!tmp.ok) return ScalarString(mkChar(tmp.msg)); })
 
 /*********************************************************************************************************************/
 /* Some helpers                                                                                                      */
 /*********************************************************************************************************************/
-static inline double asTol(SEXP tol) {
-    return asNumber(tol, "tol");
-}
-
-static inline Rboolean is_scalar_na(SEXP x) {
-    if (length(x) == 1) {
-        switch(TYPEOF(x)) {
-            case LGLSXP: return (LOGICAL(x)[0] == NA_LOGICAL);
-            case INTSXP: return (INTEGER(x)[0] == NA_INTEGER);
-            case REALSXP: return ISNAN(REAL(x)[0]);
-            case STRSXP: return (STRING_ELT(x, 0) == NA_STRING);
-        }
-    }
-    return FALSE;
-}
-
-static inline Rboolean is_vector(SEXP x) {
-    SEXP attr = ATTRIB(x);
-    if (length(attr) > 0 && (TAG(attr) != R_NamesSymbol || CDR(attr) != R_NilValue))
-        return FALSE;
-    return TRUE;
-}
-
 static msg_t check_bounds(SEXP x, SEXP lower, SEXP upper) {
     double tmp;
 
@@ -43,20 +21,18 @@ static msg_t check_bounds(SEXP x, SEXP lower, SEXP upper) {
     if (R_FINITE(tmp)) {
         if (isReal(x)) {
             const double *xp = REAL(x);
-            const double * const xend = xp + length(x);
+            const double * const xend = xp + xlength(x);
             for (; xp != xend; xp++) {
                 if (!ISNAN(*xp) && *xp < tmp)
                     return make_msg("All elements must be >= %g", tmp);
             }
         } else if (isInteger(x)) {
             const int *xp = INTEGER(x);
-            const int * const xend = xp + length(x);
+            const int * const xend = xp + xlength(x);
             for (; xp != xend; xp++) {
                 if (*xp != NA_INTEGER && *xp < tmp)
                     return make_msg("All elements must be >= %g", tmp);
             }
-        } else {
-            error("Bound checks only possible for numeric variables");
         }
     }
 
@@ -64,40 +40,27 @@ static msg_t check_bounds(SEXP x, SEXP lower, SEXP upper) {
     if (R_FINITE(tmp)) {
         if (isReal(x)) {
             const double *xp = REAL(x);
-            const double * const xend = xp + length(x);
+            const double * const xend = xp + xlength(x);
             for (; xp != xend; xp++) {
                 if (!ISNAN(*xp) && *xp > tmp)
                     return make_msg("All elements must be <= %g", tmp);
             }
         } else if (isInteger(x)) {
             const int *xp = INTEGER(x);
-            const int * const xend = xp + length(x);
+            const int * const xend = xp + xlength(x);
             for (; xp != xend; xp++) {
                 if (*xp != NA_INTEGER && *xp > tmp)
                     return make_msg("All elements must be <= %g", tmp);
             }
-        } else {
-            error("Bound checks only possible for numeric variables");
         }
     }
     return MSGT;
 }
 
-/*********************************************************************************************************************/
-/* Shared check functions returning an intermediate msg_t                                                            */
-/*********************************************************************************************************************/
-static Rboolean check_valid_names(SEXP x) {
-    return !isNull(x) && !any_missing_string(x) && all_nchar(x, 1);
-}
-
-static Rboolean check_unique_names(SEXP x) {
-    return any_duplicated(x, FALSE) == 0;
-}
-
 static Rboolean check_strict_names(SEXP x) {
-    const R_len_t nx = length(x);
+    const R_xlen_t nx = xlength(x);
     const char *str;
-    for (R_len_t i = 0; i < nx; i++) {
+    for (R_xlen_t i = 0; i < nx; i++) {
         str = CHAR(STRING_ELT(x, i));
         while (*str == '.')
             str++;
@@ -129,55 +92,76 @@ static msg_t check_names(SEXP nn, SEXP type, const char * what) {
     } else if (strcmp(expected, "strict") == 0) {
         checks = T_STRICT;
     } else {
-        error("Unknown type definition '%s'", expected);
+        error("Unknown type '%s' to specify check for names. Supported are 'unnamed', 'named', 'unique' and 'strict'.", expected);
     }
 
-    if (!check_valid_names(nn))
+    if (isNull(nn) || any_missing_string(nn) || !all_nchar(nn, 1))
         return make_msg("%s must be named", what);
     if (checks >= T_UNIQUE) {
-        if (!check_unique_names(nn))
+        if (any_duplicated(nn, FALSE) != 0)
             return make_msg("%s must be uniquely named", what);
-        if (checks == T_STRICT && !check_strict_names(nn))
+        if (checks >= T_STRICT && !check_strict_names(nn))
             return make_msg("%s must be named according to R's variable naming rules", what);
     }
-
     return MSGT;
 }
 
-static msg_t check_vector_props(SEXP x, SEXP any_missing, SEXP all_missing, SEXP len, SEXP min_len, SEXP max_len, SEXP unique, SEXP names) {
+
+static msg_t check_min_chars(SEXP x, SEXP min_chars) {
+    if (!isNull(min_chars)) {
+        R_xlen_t n = asCount(min_chars, "min.chars");
+        if (n > 0 && !all_nchar(x, n))
+            return make_msg("All elements must have at least %g characters", (double)n);
+    }
+    return MSGT;
+}
+
+static msg_t check_vector_len(SEXP x, SEXP len, SEXP min_len, SEXP max_len) {
     if (!isNull(len)) {
-        R_len_t n = asCount(len, "len");
-        if (length(x) != n)
-            return make_msg("Must have length %i, but has length %i", n, length(x));
+        R_xlen_t n = asCount(len, "len");
+        if (xlength(x) != n)
+            return make_msg("Must have length %g, but has length %g", (double)n, (double)xlength(x));
     }
-
     if (!isNull(min_len)) {
-        R_len_t n = asCount(min_len, "min.len");
-        if (length(x) < n)
-            return make_msg("Must have length >= %i, but has length %i", n, length(x));
+        R_xlen_t n = asCount(min_len, "min.len");
+        if (xlength(x) < n)
+            return make_msg("Must have length >= %g, but has length %g", (double)n, (double)xlength(x));
     }
-
     if (!isNull(max_len)) {
-        R_len_t n = asCount(max_len, "max.len");
-        if (length(x) > n)
-            return make_msg("Must have length <= %i, but has length %i", n, length(x));
+        R_xlen_t n = asCount(max_len, "max.len");
+        if (xlength(x) > n)
+            return make_msg("Must have length <= %g, but has length %g", (double)n, (double)xlength(x));
     }
+    return MSGT;
+}
 
+static msg_t check_vector_missings(SEXP x, SEXP any_missing, SEXP all_missing) {
     if (!asFlag(any_missing, "any.missing") && any_missing_atomic(x))
         return make_msg("Contains missing values");
-
     if (!asFlag(all_missing, "all.missing") && all_missing_atomic(x))
         return make_msg("Contains only missing values");
+    return MSGT;
+}
 
+static msg_t check_vector_unique(SEXP x, SEXP unique) {
     if (asFlag(unique, "unique") && any_duplicated(x, FALSE) > 0)
         return make_msg("Contains duplicated values");
+    return MSGT;
+}
 
-    if (!isNull(names) && length(x) > 0)
+static msg_t check_vector_names(SEXP x, SEXP names) {
+    if (!isNull(names) && xlength(x) > 0)
         return check_names(getAttrib(x, R_NamesSymbol), names, "Vector");
     return MSGT;
 }
 
-static msg_t check_matrix_props(SEXP x, SEXP any_missing, SEXP min_rows, SEXP min_cols, SEXP rows, SEXP cols) {
+static msg_t check_vector_finite(SEXP x, SEXP finite) {
+    if (asFlag(finite, "finite") && any_infinite(x))
+        return make_msg("Must be finite");
+    return MSGT;
+}
+
+static msg_t check_matrix_dims(SEXP x, SEXP min_rows, SEXP min_cols, SEXP rows, SEXP cols) {
     if (!isNull(min_rows) || !isNull(rows)) {
         R_len_t xrows = get_nrows(x);
         if (!isNull(min_rows)) {
@@ -204,10 +188,6 @@ static msg_t check_matrix_props(SEXP x, SEXP any_missing, SEXP min_rows, SEXP mi
                 return make_msg("Must have exactly %i cols, but has %i cols", cmp, xcols);
         }
     }
-
-    if (!asFlag(any_missing, "any.missing") && any_missing_atomic(x))
-        return make_msg("Contains missing values");
-
     return MSGT;
 }
 
@@ -251,30 +231,32 @@ static msg_t check_storage(SEXP x, SEXP mode) {
 SEXP c_check_character(SEXP x, SEXP min_chars, SEXP any_missing, SEXP all_missing, SEXP len, SEXP min_len, SEXP max_len, SEXP unique, SEXP names) {
     if (!isString(x) && !all_missing_atomic(x))
         return make_type_error(x, "character");
-    if (!isNull(min_chars)) {
-        R_len_t n = asCount(min_chars, "min.chars");
-        if (n > 0 && !all_nchar(x, n))
-            return make_result("All elements must have at least %i characters", n);
-    }
-    return mwrap(check_vector_props(x, any_missing, all_missing, len, min_len, max_len, unique, names));
+    assert(check_vector_len(x, len, min_len, max_len));
+    assert(check_vector_names(x, names));
+    assert(check_vector_missings(x, any_missing, all_missing));
+    assert(check_min_chars(x, min_chars));
+    assert(check_vector_unique(x, unique));
+    return ScalarLogical(TRUE);
 }
 
 SEXP c_check_complex(SEXP x, SEXP any_missing, SEXP all_missing, SEXP len, SEXP min_len, SEXP max_len, SEXP unique, SEXP names) {
     if (!isComplex(x) && !all_missing_atomic(x))
         return make_type_error(x, "complex");
-    return mwrap(check_vector_props(x, any_missing, all_missing, len, min_len, max_len, unique, names));
+    assert(check_vector_len(x, len, min_len, max_len));
+    assert(check_vector_names(x, names));
+    assert(check_vector_missings(x, any_missing, all_missing));
+    assert(check_vector_unique(x, unique));
+    return ScalarLogical(TRUE);
 }
 
-SEXP c_check_dataframe(SEXP x, SEXP any_missing, SEXP min_rows, SEXP min_cols, SEXP rows, SEXP cols, SEXP row_names, SEXP col_names) {
+SEXP c_check_dataframe(SEXP x, SEXP any_missing, SEXP all_missing, SEXP min_rows, SEXP min_cols, SEXP rows, SEXP cols, SEXP row_names, SEXP col_names) {
     if (!isFrame(x))
         return make_type_error(x, "data.frame");
-
-    msg_t msg = check_matrix_props(x, any_missing, min_rows, min_cols, rows, cols);
-    if (!msg.ok)
-        return make_result(msg.msg);
+    assert(check_matrix_dims(x, min_rows, min_cols, rows, cols));
 
     if (!isNull(row_names)) {
         SEXP nn = getAttrib(x, install("row.names"));
+        msg_t msg;
 
         if (isInteger(nn)) {
             nn = PROTECT(coerceVector(nn, STRSXP));
@@ -287,82 +269,88 @@ SEXP c_check_dataframe(SEXP x, SEXP any_missing, SEXP min_rows, SEXP min_cols, S
             return make_result(msg.msg);
     }
 
-    if (!isNull(col_names)) {
-        msg = check_names(getAttrib(x, R_NamesSymbol), col_names, "Columns");
-        if (!msg.ok)
-            return make_result(msg.msg);
-    }
-
+    if (!isNull(col_names))
+        assert(check_names(getAttrib(x, R_NamesSymbol), col_names, "Columns"));
+    if (!asFlag(any_missing, "any.missing") && any_missing_frame(x))
+        return make_result("Contains missing values");
+    if (!asFlag(all_missing, "all.missing") && all_missing_frame(x))
+        return make_result("Contains only missing values");
     return ScalarLogical(TRUE);
 }
 
 SEXP c_check_factor(SEXP x, SEXP any_missing, SEXP all_missing, SEXP len, SEXP min_len, SEXP max_len, SEXP unique, SEXP names) {
     if (!isFactor(x) && !all_missing_atomic(x))
         return make_type_error(x, "factor");
-    return mwrap(check_vector_props(x, any_missing, all_missing, len, min_len, max_len, unique, names));
+    assert(check_vector_len(x, len, min_len, max_len));
+    assert(check_vector_names(x, names));
+    assert(check_vector_missings(x, any_missing, all_missing));
+    assert(check_vector_unique(x, unique));
+    return ScalarLogical(TRUE);
 }
 
 SEXP c_check_integer(SEXP x, SEXP lower, SEXP upper, SEXP any_missing, SEXP all_missing, SEXP len, SEXP min_len, SEXP max_len, SEXP unique, SEXP names) {
     if (!isInteger(x) && !all_missing_atomic(x))
         return make_type_error(x, "integer");
-    msg_t msg = check_bounds(x, lower, upper);
-    if (!msg.ok)
-        return make_result(msg.msg);
-    return mwrap(check_vector_props(x, any_missing, all_missing, len, min_len, max_len, unique, names));
+    assert(check_vector_len(x, len, min_len, max_len));
+    assert(check_vector_names(x, names));
+    assert(check_vector_missings(x, any_missing, all_missing));
+    assert(check_bounds(x, lower, upper));
+    assert(check_vector_unique(x, unique));
+    return ScalarLogical(TRUE);
 }
 
 SEXP c_check_integerish(SEXP x, SEXP tol, SEXP lower, SEXP upper, SEXP any_missing, SEXP all_missing, SEXP len, SEXP min_len, SEXP max_len, SEXP unique, SEXP names) {
-    if (!isIntegerish(x, asTol(tol)) && !all_missing_atomic(x))
+    double dtol = asNumber(tol, "tol");
+    if (!isIntegerish(x, dtol) && !all_missing_atomic(x))
         return make_type_error(x, "integerish");
-
-    msg_t msg = check_bounds(x, lower, upper);
-    if (!msg.ok)
-        return make_result(msg.msg);
-    return mwrap(check_vector_props(x, any_missing, all_missing, len, min_len, max_len, unique, names));
+    assert(check_vector_len(x, len, min_len, max_len));
+    assert(check_vector_names(x, names));
+    assert(check_vector_missings(x, any_missing, all_missing));
+    assert(check_bounds(x, lower, upper));
+    assert(check_vector_unique(x, unique));
+    return ScalarLogical(TRUE);
 }
 
 SEXP c_check_list(SEXP x, SEXP any_missing, SEXP all_missing, SEXP len, SEXP min_len, SEXP max_len, SEXP unique, SEXP names) {
     if (!isRList(x))
         return make_type_error(x, "list");
-    return mwrap(check_vector_props(x, any_missing, all_missing, len, min_len, max_len, unique, names));
+    assert(check_vector_len(x, len, min_len, max_len));
+    assert(check_vector_names(x, names));
+    assert(check_vector_missings(x, any_missing, all_missing));
+    assert(check_vector_unique(x, unique));
+    return ScalarLogical(TRUE);
 }
 
 SEXP c_check_logical(SEXP x, SEXP any_missing, SEXP all_missing, SEXP len, SEXP min_len, SEXP max_len, SEXP unique, SEXP names) {
     if (!isLogical(x) && !all_missing_atomic(x))
         return make_type_error(x, "logical");
-    return mwrap(check_vector_props(x, any_missing, all_missing, len, min_len, max_len, unique, names));
+    assert(check_vector_len(x, len, min_len, max_len));
+    assert(check_vector_names(x, names));
+    assert(check_vector_missings(x, any_missing, all_missing));
+    assert(check_vector_unique(x, unique));
+    return ScalarLogical(TRUE);
 }
 
-SEXP c_check_matrix(SEXP x, SEXP mode, SEXP any_missing, SEXP min_rows, SEXP min_cols, SEXP rows, SEXP cols, SEXP row_names, SEXP col_names) {
+SEXP c_check_matrix(SEXP x, SEXP mode, SEXP any_missing, SEXP all_missing, SEXP min_rows, SEXP min_cols, SEXP rows, SEXP cols, SEXP row_names, SEXP col_names) {
     if (!isMatrix(x))
         return make_type_error(x, "matrix");
+    assert(check_storage(x, mode));
+    assert(check_matrix_dims(x, min_rows, min_cols, rows, cols));
 
-    msg_t msg = check_storage(x, mode);
-    if (!msg.ok)
-        return make_result(msg.msg);
-
-    msg = check_matrix_props(x, any_missing, min_rows, min_cols, rows, cols);
-    if (!msg.ok)
-        return make_result(msg.msg);
-
-    if (!isNull(row_names) && length(x) > 0) {
+    if (!isNull(row_names) && xlength(x) > 0) {
         SEXP nn = getAttrib(x, R_DimNamesSymbol);
         if (!isNull(nn))
             nn = VECTOR_ELT(nn, 0);
-        msg = check_names(nn, row_names, "Rows");
-        if (!msg.ok)
-            return make_result(msg.msg);
+        assert(check_names(nn, row_names, "Rows"));
     }
 
-    if (!isNull(col_names) && length(x) > 0) {
+    if (!isNull(col_names) && xlength(x) > 0) {
         SEXP nn = getAttrib(x, R_DimNamesSymbol);
         if (!isNull(nn))
             nn = VECTOR_ELT(nn, 1);
-        msg = check_names(nn, col_names, "Columns");
-        if (!msg.ok)
-            return make_result(msg.msg);
+        assert(check_names(nn, col_names, "Columns"));
     }
-
+    assert(check_vector_missings(x, any_missing, all_missing));
     return ScalarLogical(TRUE);
 }
 
@@ -370,28 +358,26 @@ SEXP c_check_array(SEXP x, SEXP mode, SEXP any_missing, SEXP d, SEXP min_d, SEXP
     if (!isArray(x))
         return make_type_error(x, "array");
 
-    msg_t msg = check_storage(x, mode);
-    if (!msg.ok)
-        return make_result(msg.msg);
+    assert(check_storage(x, mode));
 
     if (!asFlag(any_missing, "any.missing") && any_missing_atomic(x))
         return make_result("Contains missing values");
 
     R_len_t ndim = length(getAttrib(x, R_DimSymbol));
     if (!isNull(d)) {
-        int di = asCount(d, "d");
+        R_len_t di = asCount(d, "d");
         if (ndim != di)
             return make_result("Must be a %i-d array, but has dimension %i", di, ndim);
     }
 
     if (!isNull(min_d)) {
-        int di = asCount(min_d, "min.d");
+        R_len_t di = asCount(min_d, "min.d");
         if (ndim < di)
             return make_result("Must have >=%i dimensions, but has dimension %i", di, ndim);
     }
 
     if (!isNull(max_d)) {
-        int di = asCount(max_d, "max.d");
+        R_len_t di = asCount(max_d, "max.d");
         if (ndim > di)
             return make_result("Must have <=%i dimensions, but has dimension %i", di, ndim);
     }
@@ -400,52 +386,84 @@ SEXP c_check_array(SEXP x, SEXP mode, SEXP any_missing, SEXP d, SEXP min_d, SEXP
 }
 
 SEXP c_check_named(SEXP x, SEXP type) {
-    if (!isNull(type) && length(x) > 0)
-        return mwrap(check_names(getAttrib(x, R_NamesSymbol), type, "Object"));
+    if (!isNull(type) && xlength(x) > 0)
+        assert(check_names(getAttrib(x, R_NamesSymbol), type, "Object"));
     return ScalarLogical(TRUE);
 }
 
 SEXP c_check_names(SEXP x, SEXP type) {
     if (!isString(x))
         return make_result("Must be a character vector of names");
-    return mwrap(check_names(x, type, "Object"));
+    assert(check_names(x, type, "Object"));
+    return ScalarLogical(TRUE);
 }
 
+
 SEXP c_check_numeric(SEXP x, SEXP lower, SEXP upper, SEXP finite, SEXP any_missing, SEXP all_missing, SEXP len, SEXP min_len, SEXP max_len, SEXP unique, SEXP names) {
     if (!isNumeric(x) && !all_missing_atomic(x))
         return make_type_error(x, "numeric");
-    if (asFlag(finite, "finite") && any_infinite(x))
-        return make_result("Must be finite");
-    msg_t msg = check_bounds(x, lower, upper);
-    if (!msg.ok)
-        return make_result(msg.msg);
-    return mwrap(check_vector_props(x, any_missing, all_missing, len, min_len, max_len, unique, names));
+    assert(check_vector_len(x, len, min_len, max_len));
+    assert(check_vector_names(x, names));
+    assert(check_vector_missings(x, any_missing, all_missing));
+    assert(check_bounds(x, lower, upper));
+    assert(check_vector_finite(x, finite));
+    assert(check_vector_unique(x, unique));
+    return ScalarLogical(TRUE);
 }
 
 SEXP c_check_vector(SEXP x, SEXP strict, SEXP any_missing, SEXP all_missing, SEXP len, SEXP min_len, SEXP max_len, SEXP unique, SEXP names) {
-    if (!isVector(x) || ((asFlag(strict, "strict") && !is_vector(x))))
+    if (!isVector(x))
         return make_type_error(x, "vector");
-    return mwrap(check_vector_props(x, any_missing, all_missing, len, min_len, max_len, unique, names));
+    if (asFlag(strict, "strict")) {
+        SEXP attr = ATTRIB(x);
+        if ((length(attr) > 0 && (TAG(attr) != R_NamesSymbol)) || CDR(attr) != R_NilValue)
+            return make_type_error(x, "vector");
+    }
+    assert(check_vector_len(x, len, min_len, max_len));
+    assert(check_vector_names(x, names));
+    assert(check_vector_missings(x, any_missing, all_missing));
+    assert(check_vector_unique(x, unique));
+    return ScalarLogical(TRUE);
 }
 
 SEXP c_check_atomic(SEXP x, SEXP any_missing, SEXP all_missing, SEXP len, SEXP min_len, SEXP max_len, SEXP unique, SEXP names) {
     if (!isNull(x) && !isVectorAtomic(x))
         return make_type_error(x, "atomic");
-    return mwrap(check_vector_props(x, any_missing, all_missing, len, min_len, max_len, unique, names));
+    assert(check_vector_len(x, len, min_len, max_len));
+    assert(check_vector_names(x, names));
+    assert(check_vector_missings(x, any_missing, all_missing));
+    assert(check_vector_unique(x, unique));
+    return ScalarLogical(TRUE);
 }
 
 SEXP c_check_atomic_vector(SEXP x, SEXP any_missing, SEXP all_missing, SEXP len, SEXP min_len, SEXP max_len, SEXP unique, SEXP names) {
     if (!isVectorAtomic(x))
         return make_type_error(x, "atomic vector");
-    return mwrap(check_vector_props(x, any_missing, all_missing, len, min_len, max_len, unique, names));
+    assert(check_vector_len(x, len, min_len, max_len));
+    assert(check_vector_names(x, names));
+    assert(check_vector_missings(x, any_missing, all_missing));
+    assert(check_vector_unique(x, unique));
+    return ScalarLogical(TRUE);
 }
 
 /*********************************************************************************************************************/
 /* Check functions for scalars                                                                                       */
 /*********************************************************************************************************************/
+static inline Rboolean is_scalar_na(SEXP x) {
+    if (xlength(x) == 1) {
+        switch(TYPEOF(x)) {
+            case LGLSXP: return (LOGICAL(x)[0] == NA_LOGICAL);
+            case INTSXP: return (INTEGER(x)[0] == NA_INTEGER);
+            case REALSXP: return ISNAN(REAL(x)[0]);
+            case STRSXP: return (STRING_ELT(x, 0) == NA_STRING);
+        }
+    }
+    return FALSE;
+}
+
 SEXP c_check_flag(SEXP x, SEXP na_ok) {
     Rboolean is_na = is_scalar_na(x);
-    if (length(x) != 1 || (!is_na && !isLogical(x)))
+    if (xlength(x) != 1 || (!is_na && !isLogical(x)))
         return make_type_error(x, "logical flag");
     if (is_na && !asFlag(na_ok, "na.ok"))
         return make_result("May not be NA");
@@ -454,7 +472,8 @@ SEXP c_check_flag(SEXP x, SEXP na_ok) {
 
 SEXP c_check_count(SEXP x, SEXP na_ok, SEXP positive, SEXP tol) {
     Rboolean is_na = is_scalar_na(x);
-    if (length(x) != 1 || (!is_na && !isIntegerish(x, asTol(tol))))
+    double dtol = asNumber(tol, "tol");
+    if (xlength(x) != 1 || (!is_na && !isIntegerish(x, dtol)))
         return make_type_error(x, "count");
     if (is_na) {
         if (!asFlag(na_ok, "na.ok"))
@@ -469,32 +488,34 @@ SEXP c_check_count(SEXP x, SEXP na_ok, SEXP positive, SEXP tol) {
 
 SEXP c_check_int(SEXP x, SEXP na_ok, SEXP lower, SEXP upper, SEXP tol) {
     Rboolean is_na = is_scalar_na(x);
-    if (length(x) != 1 || (!is_na && !isIntegerish(x, asTol(tol))))
+    double dtol = asNumber(tol, "tol");
+    if (xlength(x) != 1 || (!is_na && !isIntegerish(x, dtol)))
         return make_type_error(x, "single integerish value");
     if (is_na) {
         if (!asFlag(na_ok, "na.ok"))
             return make_result("May not be NA");
     }
-    return mwrap(check_bounds(x, lower, upper));
+    assert(check_bounds(x, lower, upper));
+    return ScalarLogical(TRUE);
 }
 
 SEXP c_check_number(SEXP x, SEXP na_ok, SEXP lower, SEXP upper, SEXP finite) {
     Rboolean is_na = is_scalar_na(x);
-    if (length(x) != 1 || (!is_na && !isStrictlyNumeric(x)))
+    if (xlength(x) != 1 || (!is_na && !isStrictlyNumeric(x)))
         return make_type_error(x, "number");
     if (is_na) {
         if (!asFlag(na_ok, "na.ok"))
             return make_result("May not be NA");
         return ScalarLogical(TRUE);
     }
-    if (asFlag(finite, "finite") && any_infinite(x))
-        return make_result("Must be finite");
-    return mwrap(check_bounds(x, lower, upper));
+    assert(check_vector_finite(x, finite));
+    assert(check_bounds(x, lower, upper));
+    return ScalarLogical(TRUE);
 }
 
 SEXP c_check_string(SEXP x, SEXP na_ok) {
     Rboolean is_na = is_scalar_na(x);
-    if (length(x) != 1 || (!is_na && !isString(x)))
+    if (xlength(x) != 1 || (!is_na && !isString(x)))
         return make_type_error(x, "string");
     if (is_na && !asFlag(na_ok, "na.ok"))
         return make_result("May not be NA");
@@ -503,7 +524,7 @@ SEXP c_check_string(SEXP x, SEXP na_ok) {
 
 SEXP c_check_scalar(SEXP x, SEXP na_ok) {
     Rboolean is_na = is_scalar_na(x);
-    if (length(x) != 1 || (!is_na && !isVectorAtomic(x)))
+    if (xlength(x) != 1 || (!is_na && !isVectorAtomic(x)))
         return make_type_error(x, "atomic scalar");
     if (is_na && !asFlag(na_ok, "na.ok"))
         return make_result("May not be NA");
