@@ -2,6 +2,7 @@
 #define CHECKMATE_HELPER_H_
 
 #include <R.h>
+#define USE_RINTERNALS
 #include <Rinternals.h>
 
 Rboolean isStrictlyNumeric(SEXP);
@@ -10,7 +11,7 @@ R_len_t get_ncols(SEXP);
 R_len_t get_nrows(SEXP);
 double asNumber(SEXP, const char *);
 const char * asString(SEXP, const char *);
-R_len_t asCount(SEXP, const char *);
+R_xlen_t asCount(SEXP, const char *);
 Rboolean asFlag(SEXP, const char *);
 
 #endif
