@@ -2,9 +2,9 @@ context("checkNumeric")
 
 test_that("checkNumeric", {
   myobj = 1
-  expect_succ(Numeric, myobj)
+  expect_succ_all(Numeric, myobj)
   myobj = "a"
-  expect_fail(Numeric, myobj)
+  expect_fail_all(Numeric, myobj)
 
   expect_true(testNumeric(integer(0)))
   expect_false(testNumeric(NULL))
@@ -30,3 +30,19 @@ test_that("checkNumeric", {
 
   expect_error(assertNumeric("a"), "numeric")
 })
+
+test_that("bounds are checked", {
+  expect_error(checkNumeric(1, lower = "a"), "number")
+  expect_error(checkNumeric(1, lower = 1:2), "number")
+  expect_error(checkNumeric(1, lower = NA_real_), "missing")
+  expect_error(checkNumeric(1, upper = "a"), "number")
+  expect_error(checkNumeric(1, upper = 1:2), "number")
+  expect_error(checkNumeric(1, upper = NA_real_), "missing")
+})
+
+test_that("bounds of vectors with only missings are not checked", {
+  expect_true(checkNumeric(NA, lower = 1))
+  expect_true(checkNumeric(NA_character_, upper = 10))
+  expect_fail_all(Numeric, 0:5, lower = 1L)
+  expect_fail_all(Numeric, 5:15, upper = 10L)
+})
