@@ -2,9 +2,9 @@ context("checkString")
 
 test_that("checkString", {
   myobj = "a"
-  expect_succ(String, myobj)
+  expect_succ_all(String, myobj)
   myobj = 1L
-  expect_fail(String, myobj)
+  expect_fail_all(String, myobj)
 
   expect_false(testString(character(0)))
   expect_false(testString(NULL))
